@@ -17,6 +17,9 @@ class TextSequencePadding:
 
         return result_list
 
+    def __call__(self, input_data):
+        return self.fit(input_data)
+
     def _process_line(self, line_data: List[str]) -> List[str]:
         # early stop
         if len(line_data) == self.length:
@@ -29,4 +32,3 @@ class TextSequencePadding:
         padding_list = [self.value] * (self.length - len(line_data))
 
         return line_data + padding_list
-
